@@ -28,7 +28,6 @@
 
 #include "xf86.h"
 #include "os.h"
-#include "mibank.h"
 #include "globals.h"
 #include "xf86.h"
 #include "xf86Priv.h"
@@ -36,6 +35,7 @@
 #include "xf86Module.h"
 #include "mipointer.h"
 #include "windowstr.h"
+#include "inputstr.h"
 #include <X11/extensions/randr.h>
 #include <randrstr.h>
 
@@ -55,20 +55,21 @@ typedef struct _GXRandRInfo
     Rotation supported_rotations;      /* driver supported */
 } XF86RandRInfoRec, *XF86RandRInfoPtr;
 
-#define AMD_OLDPRIV (GET_ABI_MAJOR(ABI_VIDEODRV_VERSION) < 4)
-
-#if AMD_OLDPRIV
-
-static int GXRandRIndex;
-
-#define XF86RANDRINFO(p) ((XF86RandRInfoPtr) (p)->devPrivates[GXRandRIndex].ptr)
+#if HAS_DEVPRIVATEKEYREC
+static DevPrivateKeyRec GXRandRIndex;
 #else
+static int GXRandRIndex;
+#endif
 
-static DevPrivateKey GXRandRKey;
-
-#define XF86RANDRINFO(p) ((XF86RandRInfoPtr) \
-			  dixLookupPrivate(&(p)->devPrivates, GXRandRKey));
+#define OLD_VIDEODRV_INTERFACE (GET_ABI_MAJOR(ABI_VIDEODRV_VERSION) < 4)
 
+#if OLD_VIDEODRV_INTERFACE
+#define XF86RANDRINFO(p)   ((XF86RandRInfoPtr) (p)->devPrivates[GXRandRIndex].ptr)
+#define XF86RANDRSET(p, v) (p)->devPrivates[GXRandRIndex].ptr = v
+#else
+#define XF86RANDRINFO(p) ((XF86RandRInfoPtr)						\
+			  dixLookupPrivate(&(p)->devPrivates, &GXRandRIndex))
+#define XF86RANDRSET(p, v) dixSetPrivate(&(p)->devPrivates, &GXRandRIndex, v)
 #endif
 
 static int
@@ -163,7 +164,11 @@ GXRandRSetMode(ScreenPtr pScreen,
     int oldHeight = pScreen->height;
     int oldmmWidth = pScreen->mmWidth;
     int oldmmHeight = pScreen->mmHeight;
+#if GET_ABI_MAJOR(ABI_VIDEODRV_VERSION) < 8
     WindowPtr pRoot = WindowTable[pScreen->myNum];
+#else
+    WindowPtr pRoot = pScreen->root;
+#endif
     DisplayModePtr currentMode = NULL;
     Bool ret = TRUE;
     PixmapPtr pspix = NULL;
@@ -209,7 +214,7 @@ GXRandRSetMode(ScreenPtr pScreen,
      * Get the new Screen pixmap ptr as SwitchMode might have called
      * ModifyPixmapHeader and xf86EnableDisableFBAccess will put it back...
      * Unfortunately.
-
+     
      */
 
     pspix = (*pScreen->GetScreenPixmap) (pScreen);
@@ -248,7 +253,7 @@ GXRandRSetConfig(ScreenPtr pScreen, Rotation rotation,
     }
 
 /* FIXME: we don't have a new video ABI yet */
-#if GET_ABI_MAJOR(ABI_XINPUT_VERSION) == 3
+#if GET_ABI_MAJOR(ABI_XINPUT_VERSION) >= 3
     miPointerGetPosition(inputInfo.pointer, &px, &py);
 #else
     miPointerPosition(&px, &py);
@@ -292,7 +297,7 @@ GXRandRSetConfig(ScreenPtr pScreen, Rotation rotation,
     }
 
 /* FIXME: we don't have a new video ABI yet */
-#if GET_ABI_MAJOR(ABI_XINPUT_VERSION) == 3
+#if GET_ABI_MAJOR(ABI_XINPUT_VERSION) >= 3
     if (pScreen == miPointerGetScreen(inputInfo.pointer))
 #else
     if (pScreen == miPointerCurrentScreen())
@@ -305,12 +310,10 @@ GXRandRSetConfig(ScreenPtr pScreen, Rotation rotation,
 
 /* FIXME: we don't have a new video ABI yet */
 	(*pScreen->SetCursorPosition) (
-#if GET_ABI_MAJOR(ABI_XINPUT_VERSION) == 3
+#if GET_ABI_MAJOR(ABI_XINPUT_VERSION) >= 3
                                         inputInfo.pointer,
 #endif
-                                        pScreen,
-                                        px, py,
-                                        FALSE);
+	    pScreen, px, py, FALSE);
     }
 
     return TRUE;
@@ -333,10 +336,12 @@ GXRandRInit(ScreenPtr pScreen, int rotation)
     if (GXRandRGeneration != serverGeneration) {
 	GXRandRGeneration = serverGeneration;
     }
-#if AMD_OLDPRIV
+#if OLD_VIDEODRV_INTERFACE
     GXRandRIndex = AllocateScreenPrivateIndex();
-#else
-    GXRandRKey = &GXRandRKey;
+#endif
+#if HAS_DIXREGISTERPRIVATEKEY
+    if (!dixRegisterPrivateKey(&GXRandRIndex, PRIVATE_SCREEN, 0))
+	return FALSE;
 #endif
 
     pRandr = xcalloc(sizeof(XF86RandRInfoRec), 1);
@@ -362,10 +367,7 @@ GXRandRInit(ScreenPtr pScreen, int rotation)
     pRandr->supported_rotations = rotation;
     pRandr->maxX = pRandr->maxY = 0;
 
-#if AMD_OLDPRIV
-    pScreen->devPrivates[GXRandRIndex].ptr = pRandr;
-#else
-    dixSetPrivate(&pScreen->devPrivates, GXRandRKey, pRandr);
-#endif
+    XF86RANDRSET(pScreen, pRandr);
+
     return TRUE;
 }
